#
# spec file for package python-openqa_review
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         short_name openqa_review
Name:           python-%{short_name}
Version:        1.4.0
Release:        1.2
Summary:        A review helper script for openQA
License:        MIT
Group:          Development/Languages/Python
Source:         https://github.com/okurz/%{short_name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Url:            https://github.com/okurz/%{short_name}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-setuptools
Requires:       python-PyYAML
Requires:       python-beautifulsoup4
Requires:       python-future
Requires:       python-humanfriendly
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-sortedcontainers
BuildArch:      noarch

%description
A review helper script for openQA. For more details look into the README file.

%prep
%setup -q -n %{short_name}-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{python_sitelib}
%attr(755, -, -) %{_bindir}/openqa-review
%attr(755, -, -) %{_bindir}/openqa-review-sles-ha
%attr(755, -, -) %{_bindir}/tumblesle-release

%changelog
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 1.4.0:
  * Add tumblesle example scripts
  * Use index.json to get job groups (#36)
  * Prepare for wellformed json (#38)
  * Fix #41: Handle broken bugrefs gracefully (#42)
  * Fix for parent groups: Use API to get job_groups (#43)
  * Use JSON version of group_overview (#44)
  * TODO: Add entry about configparser travis error
  * Ensure configparser is available for py2+3
  * Fix py27 errors only observable on travis
  * Handle job groups with builds not having any 'done' jobs at all
  * Try to get distri/version for each build (#47)
  * Ensure proper URL concatenation on py2 for bug details retrieval
  * Show parent group in report (#48)
  * Add tumblesle helper script for 12sp3
  * Add update_jekyll for tumblesle release
  * Use blank build value without version prefix (#51)
  * Comment on old bugs with new failed test url (#50)
  * Fix flake8 reported issues after 48fb659
  * Fix parsing of job groups after openQA#9b50b22
  * Run all envs on travis
  * Add command line option for '--min-days-unchanged' for reminder comments
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.2:
  * Fix crash on new-style 'empty builds'
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * Debug output for 'not enough builds'
  * Get rid of possibly already covered exception handling
  * bin: Mark script as executable
  * dashboard: Customize html header content, e.g. title
  * tumblesle_release: Regard 'softfailed' in newer versions of openQA as passed
* Thu Oct  6 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * tests: Correct test files for 'after_61b4db60'
  * Prevent "no builds" found for weird combination of python packages for some users
* Thu Sep 29 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.0:
  * report_links: Make 'latest' a link in markdown format
  * wip -- add bug report links, also for progress, for later
  * TODO: correct indendation of some entries
  * TODO: Remove implemented bug reporting links
  * browser: Support saving pages with unicode content in python2
  * issue_report_link: Support non-digit builds
  * issue_report_link: Handle non-existing product mapping option gracefully
  * Allow filtering for closed / unassigned bugs
  * TODO: Add some ideas
  * Add dashboard generation script
  * Store dashboard file at common "bin" location
  * Delete unnecessary bootstrap.js and font files
  * Add LICENSE.GPL-2 for files under dashboard_files/
  * dashboard: Use robust 'sh -e' shebang
  * Add bin/openqa_review_osd_daily_email script
  * dashboard: Make all variables options with defaults
  * dashboard: Replace three-step sed replace by proper template replace
  * dashboard: Customize logo with a big 'R' on top for 'review'
  * Merge 'dashboard' and 'openqa_review_osd_daily_email'
  * issue_report_link: Fix unsupported failures without failed modules
  * TODO: Mark 'use test verbosity for existing' as fixed
  * Do not fail when there are no closed/unass bugs (#28)
  * Fix #21: Put hr to own line and use md syntax (#29)
  * Make hr between products on dashboard page thicker (#31)
  * Fix ") in issue subject breaking markdown (#30)
  * Support new-style progress bars of openQA
* Wed Sep 21 2016 opensuse-packaging@opensuse.org
- Update to version 1.2.0:
  * Display ticket priority (#25)
  * Show __doc__ as port of help
  * Add links to verbose reports to directly report bugs
  * Use host specific issue tracker product mapping
  * Ensure multiple missing archs are sorted
  * Add more information to bug report links
* Tue Sep 20 2016 opensuse-packaging@opensuse.org
- Update to version 1.1.0:
  * Get objects up into the main function (#22)
  * Fix arch matching (#23)
  * Treat incomplete->failed as new failures
* Mon Sep 19 2016 opensuse-packaging@opensuse.org
- Update to version 1.0.0:
  * Simplify script usage (#13)
  * Add Browser cache (#15)
  * Be more strict about bugrefs read on openQA webpages
  * Use Objects to handle Issues and ArchReport
  * Add .swp files to .gitignore
  * Fix soft failed: Use new 'result_softfailed' str
  * TODO: Add idea about bug reporting links
  * Add ArchReports and IssueEntry obj (#19)
  * '-r' and '-T' are not mutually exclusive anymore
  * Get objects up into the main function (#22)
* Tue Sep 13 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.1:
  * Fix 'missing architectures' entry not yielding proper table row
  * Fix D403 style issues
  * Prevent flake8 check running on existing .tox dir
  * Ensure proper python2+3 testing on different distributions
  * TODO: DONE "Using labels …" with commit fd1b373
  * TODO: DONE "package for openSUSE"
* Mon Sep 12 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.0:
  * Read Bugzilla issue status & subject (#8)
  * Fix config parsing for python2 (#9)
  * Fix insecure ssl warning (#10)
  * TODO: Add reference to mass bug filing tool
  * Let --query-issue-status" arg implie --bugrefs (#11)
  * Extract Browser into module
  * Extract report generator object for 'new issue'
  * Use absolute imports for python2
* Thu Aug 25 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.1:
  * .travis.yml: Add pypi deploy commands
  * Correct name in setup.py to 'openqa_review'
  * Add reference for pypi deploy to .travis.yml
  * Accept 'not enough finished builds' as expected behaviour
  * Prevent inactive job groups showing up in openQA >= 4.4
  * Add wrapper script for SLES/HA review
  * Correct markdown syntax of code segments
  * Handle download errors graciously
  * Correct log message for saving files in Browser
  * Fix 'KeyError TODO' with builds having only bugref'd jobs
* Sun Jan 24 2016 okurz@suse.de
- initial package
